require 'core_models/i18n/i18n_helper'

module CoreModels
  class Base::Region < ActiveRecord::Base
    has_and_belongs_to_many :names,
      :class_name => '::CoreModels::I18n::I18nString',
      :join_table => 'core_base_regions_i18n_strings',
      :validate => true #, :dependent => :destroy
    accepts_nested_attributes_for :names

    belongs_to :country

    has_many :towns
    has_many :addresses

    #validates :names, :presence => true
    validates :country, :presence => true

    #---------- Callbacks

    after_save     :after_save_handler
    before_destroy :before_destroy_handler

    #---------- Helpers

    def to_s
      best_name_value
    end

    # get all towns in a particular region
    def self.towns(region = nil)
      if self.nil?
        return region.nil? ? Town.all : Town.find_all_by_region(region)
      else
        return Town.find_all_by_region(self)
      end
    end

    def self.in_country?(country = nil)
      unless country.nil?
        @regions = Region.find_all_by_country(country)
      else
        @regions = Region.all
      end

      @regions
    end

    def best_name_value(requested_locale = nil)
      best_name(requested_locale).nil? ? '' : best_name(requested_locale).value
    end

    def best_name(requested_locale = nil)
      I18nHelper::best_i18n_string(names,requested_locale)
    end

    #---------- Callback handlers

    private

    def after_save_handler
      I18nHelper::fill_i18n_strings(self.names)
    end

    def before_destroy_handler
      # Cleanup names
      I18nHelper::destroy_i18n_strings(self.names)
    end
  end
end
