require 'core_models/i18n/i18n_helper'

module CoreModels
  class Base::Town < ActiveRecord::Base
    has_and_belongs_to_many :names,
      :class_name => '::CoreModels::I18n::I18nString',
      :join_table => 'core_base_towns_i18n_strings',
      :validate => true #, :dependent => :destroy
    accepts_nested_attributes_for :names

    belongs_to :region
    #belongs_to :country, :through => :region

    has_many :addresses

    #validates :names, :presence => true
    validates :region, :presence => true

    #---------- Callbacks

    after_save     :after_save_handler
    before_destroy :before_destroy_handler

    #---------- Helpers

    def to_s
      best_name_value
    end

    # get all addresses in a particular town
    def self.addresses(town = nil)
      if self.nil?
        return town.nil? ? Address.all : Address.find_all_by_town(town)
      else
        return Address.find_all_by_town(self)
      end
    end

    def self.in_region?(region = nil)
      unless region.nil?
        @towns = Town.find_all_by_region(region)
      else
        @towns = Town.all
      end

      @towns
    end

    def best_name_value(requested_locale = nil)
      best_name(requested_locale).nil? ? '' : best_name(requested_locale).value
    end

    def best_name(requested_locale = nil)
      I18nHelper::best_i18n_string(names,requested_locale)
    end

    #---------- Callback handlers

    private

    def after_save_handler
      I18nHelper::fill_i18n_strings(self.names)
    end

    def before_destroy_handler
      # Cleanup names
      I18nHelper::destroy_i18n_strings(self.names)
    end
  end
end
