module CoreModels
  class PeopleAndCompanies::Person < ActiveRecord::Base
    belongs_to :home_address, :class_name => '::CoreModels::Base::Address'
    belongs_to :postal_address, :class_name => '::CoreModels::Base::Address'
    belongs_to :contact_address, :class_name => '::CoreModels::Base::Address'
    accepts_nested_attributes_for :home_address
    accepts_nested_attributes_for :postal_address
    accepts_nested_attributes_for :contact_address

    belongs_to :maritial_status, :class_name => '::CoreModels::Base::MaritialStatus'
    belongs_to :gender, :class_name => '::CoreModels::Base::Gender'

    belongs_to :company, :class_name => '::CoreModels::PeopleAndCompanies::Company', :optional => true

    #has_and_belongs_to_many :photos
    has_one :person_photo, :class_name => '::CoreModels::PeopleAndCompanies::PersonPhoto'
    has_one :photo, :through => :person_photo, :class_name => '::AssetManagement::AssetData', :dependent => :destroy
    accepts_nested_attributes_for :person_photo
    accepts_nested_attributes_for :photo

    #attr_accessible :title, :forename, :middle_names, :surname, :birthdate
    #attr_accessible :email_1, :email_2, :email_3, :url_1, :url_2, :url_3
    #attr_accessible :telephone_number_1, :telephone_number_2, :telephone_number_3
    #attr_accessible :mobile_number_1, :mobile_number_2, :mobile_number_3
    #attr_accessible :fax_number_1, :fax_number_2, :fax_number_3
    #attr_accessible :health_service_reference, :id_card_number, :passport_number, :residency_number, :social_security_number
    #attr_accessible :notes

    #if ::Rails.env.test?
    #attr_accessible :home_address, :home_address_id
    #attr_accessible :postal_address, :postal_address_id
    #attr_accessible :contact_address, :contact_address_id
    #attr_accessible :maritial_status, :maritial_status_id
    #attr_accessible :gender, :gender_id
    #end

    #attr_accessible :person_photo_attributes

    validate :has_forename_or_surname

    #----------------------------------------------------------------------------

    def to_s
      display_name
    end

    def display_name
      name = ''
      name += "#{title} " unless title.blank? || surname.blank?
      name += "#{forename} " unless forename.blank?
      name += "#{surname}" unless surname.blank?
      name
    end

    #----------------------------------------------------------------------------

    private

    def has_forename_or_surname
      errors[:base] << "must have a forename and/or a surname" if (forename.blank? && surname.blank?)
    end
  end
end
